@@ -1,7 +1,7 @@
 module Pundit
   module Generators
     class PolicyGenerator < ::Rails::Generators::NamedBase
-      source_root File.expand_path(File.join(File.dirname(__FILE__), 'templates'))
+      source_root File.expand_path('templates', __dir__)
 
       def create_policy
         template 'policy.rb', File.join('app/policies', class_path, "#{file_name}_policy.rb")
